xclim Official Documentation
============================

.. toctree::
   :maxdepth: 0
   :caption: Table of Contents:

   self

.. toctree::
   :maxdepth: 2

   About <readme>
   installation
   notebooks/usage
   notebooks/index
   indicators
   indices
   checks
   notebooks/units
   internationalization
   notebooks/cli
   sdba
   analogues
   contributing
   authors
   history
   references

.. toctree::
   :maxdepth: 2
   :caption: User API

   api

.. toctree::
   :maxdepth: 1
   :caption: All Modules

   modules

.. only:: html

    Indices and tables
    ==================
    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`
